==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/AuthInfoFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AuthInfoFluent<A extends io.fabric8.kubernetes.api.model.AuthInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAs();
  public A withAs(java.lang.String as);
  public java.lang.Boolean hasAs();
  
  /**
   * Method is deprecated. use withAs instead.
   */
  @java.lang.Deprecated
  public A withNewAs(java.lang.String arg0);
  public A addToAsGroups(java.lang.Integer index,java.lang.String item);
  public A setToAsGroups(java.lang.Integer index,java.lang.String item);
  public A addToAsGroups(java.lang.String... items);
  public A addAllToAsGroups(java.util.Collection<java.lang.String> items);
  public A removeFromAsGroups(java.lang.String... items);
  public A removeAllFromAsGroups(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getAsGroups();
  public java.lang.String getAsGroup(java.lang.Integer index);
  public java.lang.String getFirstAsGroup();
  public java.lang.String getLastAsGroup();
  public java.lang.String getMatchingAsGroup(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingAsGroup(java.util.function.Predicate<java.lang.String> predicate);
  public A withAsGroups(java.util.List<java.lang.String> asGroups);
  public A withAsGroups(java.lang.String... asGroups);
  public java.lang.Boolean hasAsGroups();
  public A addNewAsGroup(java.lang.String arg0);
  public A addToAsUserExtra(java.lang.String key,java.util.ArrayList<java.lang.String> value);
  public A addToAsUserExtra(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public A removeFromAsUserExtra(java.lang.String key);
  public A removeFromAsUserExtra(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> getAsUserExtra();
  public <K,V>A withAsUserExtra(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> asUserExtra);
  public java.lang.Boolean hasAsUserExtra();
  
  /**
   * This method has been deprecated, please use method buildAuthProvider instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.AuthProviderConfig getAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthProviderConfig buildAuthProvider();
  public A withAuthProvider(io.fabric8.kubernetes.api.model.AuthProviderConfig authProvider);
  public java.lang.Boolean hasAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> withNewAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> withNewAuthProviderLike(io.fabric8.kubernetes.api.model.AuthProviderConfig item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> editAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> editOrNewAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> editOrNewAuthProviderLike(io.fabric8.kubernetes.api.model.AuthProviderConfig item);
  public java.lang.String getClientCertificate();
  public A withClientCertificate(java.lang.String clientCertificate);
  public java.lang.Boolean hasClientCertificate();
  
  /**
   * Method is deprecated. use withClientCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificate(java.lang.String arg0);
  public java.lang.String getClientCertificateData();
  public A withClientCertificateData(java.lang.String clientCertificateData);
  public java.lang.Boolean hasClientCertificateData();
  
  /**
   * Method is deprecated. use withClientCertificateData instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificateData(java.lang.String arg0);
  public java.lang.String getClientKey();
  public A withClientKey(java.lang.String clientKey);
  public java.lang.Boolean hasClientKey();
  
  /**
   * Method is deprecated. use withClientKey instead.
   */
  @java.lang.Deprecated
  public A withNewClientKey(java.lang.String arg0);
  public java.lang.String getClientKeyData();
  public A withClientKeyData(java.lang.String clientKeyData);
  public java.lang.Boolean hasClientKeyData();
  
  /**
   * Method is deprecated. use withClientKeyData instead.
   */
  @java.lang.Deprecated
  public A withNewClientKeyData(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildExec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ExecConfig getExec();
  public io.fabric8.kubernetes.api.model.ExecConfig buildExec();
  public A withExec(io.fabric8.kubernetes.api.model.ExecConfig exec);
  public java.lang.Boolean hasExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> withNewExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> withNewExecLike(io.fabric8.kubernetes.api.model.ExecConfig item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> editExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> editOrNewExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> editOrNewExecLike(io.fabric8.kubernetes.api.model.ExecConfig item);
  public A addToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A setToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A addToExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A addAllToExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeFromExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A removeAllFromExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeMatchingFromExtensions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExtensions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> getExtensions();
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> buildExtensions();
  public io.fabric8.kubernetes.api.model.NamedExtension buildExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NamedExtension buildFirstExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildLastExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public java.lang.Boolean hasMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public A withExtensions(java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> extensions);
  public A withExtensions(io.fabric8.kubernetes.api.model.NamedExtension... extensions);
  public java.lang.Boolean hasExtensions();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> addNewExtension();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> addNewExtensionLike(io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> setNewExtensionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editFirstExtension();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editLastExtension();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public java.lang.String getPassword();
  public A withPassword(java.lang.String password);
  public java.lang.Boolean hasPassword();
  
  /**
   * Method is deprecated. use withPassword instead.
   */
  @java.lang.Deprecated
  public A withNewPassword(java.lang.String arg0);
  public java.lang.String getToken();
  public A withToken(java.lang.String token);
  public java.lang.Boolean hasToken();
  
  /**
   * Method is deprecated. use withToken instead.
   */
  @java.lang.Deprecated
  public A withNewToken(java.lang.String arg0);
  public java.lang.String getTokenFile();
  public A withTokenFile(java.lang.String tokenFile);
  public java.lang.Boolean hasTokenFile();
  
  /**
   * Method is deprecated. use withTokenFile instead.
   */
  @java.lang.Deprecated
  public A withNewTokenFile(java.lang.String arg0);
  public java.lang.String getUsername();
  public A withUsername(java.lang.String username);
  public java.lang.Boolean hasUsername();
  
  /**
   * Method is deprecated. use withUsername instead.
   */
  @java.lang.Deprecated
  public A withNewUsername(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface AuthProviderNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.AuthProviderConfigFluent<io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<N>>{
    public N and();
    public N endAuthProvider();
    
  }
  public interface ExecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ExecConfigFluent<io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<N>>{
    public N and();
    public N endExec();
    
  }
  public interface ExtensionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NamedExtensionFluent<io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<N>>{
    public N and();
    public N endExtension();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/AuthInfoFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AuthInfoFluent<A extends io.fabric8.kubernetes.api.model.AuthInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAs();
  public A withAs(java.lang.String as);
  public java.lang.Boolean hasAs();
  
  /**
   * Method is deprecated. use withAs instead.
   */
  @java.lang.Deprecated
  public A withNewAs(java.lang.String arg0);
  public A addToAsGroups(java.lang.Integer index,java.lang.String item);
  public A setToAsGroups(java.lang.Integer index,java.lang.String item);
  public A addToAsGroups(java.lang.String... items);
  public A addAllToAsGroups(java.util.Collection<java.lang.String> items);
  public A removeFromAsGroups(java.lang.String... items);
  public A removeAllFromAsGroups(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getAsGroups();
  public java.lang.String getAsGroup(java.lang.Integer index);
  public java.lang.String getFirstAsGroup();
  public java.lang.String getLastAsGroup();
  public java.lang.String getMatchingAsGroup(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingAsGroup(java.util.function.Predicate<java.lang.String> predicate);
  public A withAsGroups(java.util.List<java.lang.String> asGroups);
  public A withAsGroups(java.lang.String... asGroups);
  public java.lang.Boolean hasAsGroups();
  public A addNewAsGroup(java.lang.String arg0);
  public java.lang.String getAsUid();
  public A withAsUid(java.lang.String asUid);
  public java.lang.Boolean hasAsUid();
  
  /**
   * Method is deprecated. use withAsUid instead.
   */
  @java.lang.Deprecated
  public A withNewAsUid(java.lang.String arg0);
  public A addToAsUserExtra(java.lang.String key,java.util.ArrayList<java.lang.String> value);
  public A addToAsUserExtra(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public A removeFromAsUserExtra(java.lang.String key);
  public A removeFromAsUserExtra(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map);
  public java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> getAsUserExtra();
  public <K,V>A withAsUserExtra(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> asUserExtra);
  public java.lang.Boolean hasAsUserExtra();
  
  /**
   * This method has been deprecated, please use method buildAuthProvider instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.AuthProviderConfig getAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthProviderConfig buildAuthProvider();
  public A withAuthProvider(io.fabric8.kubernetes.api.model.AuthProviderConfig authProvider);
  public java.lang.Boolean hasAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> withNewAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> withNewAuthProviderLike(io.fabric8.kubernetes.api.model.AuthProviderConfig item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> editAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> editOrNewAuthProvider();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<A> editOrNewAuthProviderLike(io.fabric8.kubernetes.api.model.AuthProviderConfig item);
  public java.lang.String getClientCertificate();
  public A withClientCertificate(java.lang.String clientCertificate);
  public java.lang.Boolean hasClientCertificate();
  
  /**
   * Method is deprecated. use withClientCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificate(java.lang.String arg0);
  public java.lang.String getClientCertificateData();
  public A withClientCertificateData(java.lang.String clientCertificateData);
  public java.lang.Boolean hasClientCertificateData();
  
  /**
   * Method is deprecated. use withClientCertificateData instead.
   */
  @java.lang.Deprecated
  public A withNewClientCertificateData(java.lang.String arg0);
  public java.lang.String getClientKey();
  public A withClientKey(java.lang.String clientKey);
  public java.lang.Boolean hasClientKey();
  
  /**
   * Method is deprecated. use withClientKey instead.
   */
  @java.lang.Deprecated
  public A withNewClientKey(java.lang.String arg0);
  public java.lang.String getClientKeyData();
  public A withClientKeyData(java.lang.String clientKeyData);
  public java.lang.Boolean hasClientKeyData();
  
  /**
   * Method is deprecated. use withClientKeyData instead.
   */
  @java.lang.Deprecated
  public A withNewClientKeyData(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildExec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ExecConfig getExec();
  public io.fabric8.kubernetes.api.model.ExecConfig buildExec();
  public A withExec(io.fabric8.kubernetes.api.model.ExecConfig exec);
  public java.lang.Boolean hasExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> withNewExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> withNewExecLike(io.fabric8.kubernetes.api.model.ExecConfig item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> editExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> editOrNewExec();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<A> editOrNewExecLike(io.fabric8.kubernetes.api.model.ExecConfig item);
  public A addToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A setToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A addToExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A addAllToExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeFromExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A removeAllFromExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeMatchingFromExtensions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExtensions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> getExtensions();
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> buildExtensions();
  public io.fabric8.kubernetes.api.model.NamedExtension buildExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NamedExtension buildFirstExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildLastExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public java.lang.Boolean hasMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public A withExtensions(java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> extensions);
  public A withExtensions(io.fabric8.kubernetes.api.model.NamedExtension... extensions);
  public java.lang.Boolean hasExtensions();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> addNewExtension();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> addNewExtensionLike(io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> setNewExtensionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editFirstExtension();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editLastExtension();
  public io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<A> editMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public java.lang.String getPassword();
  public A withPassword(java.lang.String password);
  public java.lang.Boolean hasPassword();
  
  /**
   * Method is deprecated. use withPassword instead.
   */
  @java.lang.Deprecated
  public A withNewPassword(java.lang.String arg0);
  public java.lang.String getToken();
  public A withToken(java.lang.String token);
  public java.lang.Boolean hasToken();
  
  /**
   * Method is deprecated. use withToken instead.
   */
  @java.lang.Deprecated
  public A withNewToken(java.lang.String arg0);
  public java.lang.String getTokenFile();
  public A withTokenFile(java.lang.String tokenFile);
  public java.lang.Boolean hasTokenFile();
  
  /**
   * Method is deprecated. use withTokenFile instead.
   */
  @java.lang.Deprecated
  public A withNewTokenFile(java.lang.String arg0);
  public java.lang.String getUsername();
  public A withUsername(java.lang.String username);
  public java.lang.Boolean hasUsername();
  
  /**
   * Method is deprecated. use withUsername instead.
   */
  @java.lang.Deprecated
  public A withNewUsername(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface AuthProviderNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.AuthProviderConfigFluent<io.fabric8.kubernetes.api.model.AuthInfoFluent.AuthProviderNested<N>>{
    public N and();
    public N endAuthProvider();
    
  }
  public interface ExecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ExecConfigFluent<io.fabric8.kubernetes.api.model.AuthInfoFluent.ExecNested<N>>{
    public N and();
    public N endExec();
    
  }
  public interface ExtensionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NamedExtensionFluent<io.fabric8.kubernetes.api.model.AuthInfoFluent.ExtensionsNested<N>>{
    public N and();
    public N endExtension();
    
  }
  
}
